@@ -14,9 +14,11 @@ import annofabcli.labor.subcommand_labor
 import annofabcli.organization_member.subcommand_organization_member
 import annofabcli.project.subcommand_project
 import annofabcli.project_member.subcommand_project_member
+import annofabcli.stat_visualization.subcommand_stat_visualization
 import annofabcli.statistics.subcommand_statistics
 import annofabcli.supplementary.subcommand_supplementary
 import annofabcli.task.subcommand_task
+import annofabcli.task_history.subcommand_task_history
 
 logger = logging.getLogger(__name__)
 
@@ -31,7 +33,9 @@ def main(arguments: Optional[Sequence[str]] = None):
 
     """
 
-    parser = argparse.ArgumentParser(description="Command Line Interface for AnnoFab")
+    parser = argparse.ArgumentParser(
+        description="Command Line Interface for AnnoFab", formatter_class=argparse.ArgumentDefaultsHelpFormatter
+    )
     parser.add_argument("--version", action="version", version=f"annofabcli {annofabcli.__version__}")
     parser.set_defaults(command_help=parser.print_help)
 
@@ -48,8 +52,10 @@ def main(arguments: Optional[Sequence[str]] = None):
     annofabcli.project.subcommand_project.add_parser(subparsers)
     annofabcli.project_member.subcommand_project_member.add_parser(subparsers)
     annofabcli.statistics.subcommand_statistics.add_parser(subparsers)
+    annofabcli.stat_visualization.subcommand_stat_visualization.add_parser(subparsers)
     annofabcli.supplementary.subcommand_supplementary.add_parser(subparsers)
     annofabcli.task.subcommand_task.add_parser(subparsers)
+    annofabcli.task_history.subcommand_task_history.add_parser(subparsers)
 
     annofabcli.filesystem.subcommand_filesystem.add_parser(subparsers)
     annofabcli.experimental.subcommand_experimental.add_parser(subparsers)
